==> RSTouchscreenNG-1.3.0.zip: RSTouchscreenNG/projects/binding/src/lib/reducer/UserReducer.ts <==
/* (C) 2016-2021 Hot-World GmbH & Co. KG <rlittwin@repetier.com>
 All Rights Reserved

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
 DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

 It is allowed to use this code to create or use in products connecting to
 Repetier-Server or to use it for own plugins/modules with Repetier-Server.
 This includes free and commercial products.
 Usage for other products is strictly forbidden.
 */

import {INITIAL_USER_STATE} from "../state/UserState";
import type {UserState} from "../state/UserState";
import {UserSetDataAction, UserSetSettingAction} from "../actions/UserAction";
import {Action, createReducer, on} from "@ngrx/store";

function updatePermission(ustate: UserState): UserState {
  // tslint:disable-next-line
  ustate.canPrint = (ustate.permissions & 1) === 1;
  // tslint:disable-next-line
  ustate.canAddFiles = (ustate.permissions & 2) === 2;
  // tslint:disable-next-line
  ustate.canDeleteFiles = (ustate.permissions & 4) === 4;
  // tslint:disable-next-line
  ustate.canConfigure = (ustate.permissions & 8) === 8;
  ustate.isRealUser = ustate.login !== "global" && ustate.login !== "frontend";
  return ustate;
}

const reducer = createReducer(INITIAL_USER_STATE,
  on(UserSetSettingAction, (state, payload) => {
    const x = {};
    x[payload.key] = payload.value;
    return {...state, settings: {...state.settings, ...x}};
  }),
  on(UserSetDataAction, (state, payload) =>
    updatePermission(Object.assign({}, state, payload)))
);

export function UserReducer(state: UserState | undefined, action: Action) {
  try {
    return reducer(state, action);
  } catch (e) {
    console.error("UserReducer error", e);
    return state;
  }
}

==> RSTouchscreenNG-1.4.11.zip: RSTouchscreenNG/projects/binding/src/lib/reducer/UserReducer.ts <==
/* (C) 2016-2023 Hot-World GmbH & Co. KG <rlittwin@repetier.com>
 All Rights Reserved

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
 DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

 It is allowed to use this code to create or use in products connecting to
 Repetier-Server or to use it for own plugins/modules with Repetier-Server.
 This includes free and commercial products.
 Usage for other products is strictly forbidden.
 */

import {INITIAL_USER_STATE} from "../state/UserState";
import type {UserState} from "../state/UserState";
import {UserSetDataAction, UserSetSettingAction} from "../actions/UserAction";
import {Action, createReducer, on} from "@ngrx/store";

function updatePermission(ustate: UserState): UserState {
  // eslint-disable-next-line
  ustate.canPrint = (ustate.permissions & 1) === 1;
  // eslint-disable-next-line
  ustate.canAddFiles = (ustate.permissions & 2) === 2;
  // eslint-disable-next-line
  ustate.canDeleteFiles = (ustate.permissions & 4) === 4;
  // eslint-disable-next-line
  ustate.canConfigure = (ustate.permissions & 8) === 8;
  ustate.isRealUser = ustate.login !== "global" && ustate.login !== "frontend";
  return ustate;
}

const reducer = createReducer(INITIAL_USER_STATE,
  on(UserSetSettingAction, (state, payload) => {
    const x = {};
    x[payload.key] =  JSON.parse(JSON.stringify(payload.value));
    return {...state, settings: {...state.settings, ...x}};
  }),
  on(UserSetDataAction, (state, payload) =>
    updatePermission(Object.assign({}, state,  JSON.parse(JSON.stringify(payload)))))
);

export function UserReducer(state: UserState | undefined, action: Action) {
  try {
    return reducer(state, action);
  } catch (e) {
    console.error("UserReducer error", e);
    return state;
  }
}
